@@ -1,10 +1,16 @@
+class SoapRequestException(Exception):
+    def __init__(self, error, request):
+        self.error = error
+        self.request = request
+        super(SoapRequestException, self).__init__(error)
 
 
 class SoapServerException(Exception):
-    def __init__(self, error, code):
+    def __init__(self, error, code, request):
         super(SoapServerException, self).__init__(error, code)
         self.error = error
         self.code = code
+        self.request = request
 
 
 class SoapClientException(Exception):
@@ -24,4 +30,6 @@ class MethodDoesNotExist(SoapClientException):
 
 
 class InvalidSignatureResponse(SoapClientException):
-    pass
+    def __init__(self, envelope):
+        super(InvalidSignatureResponse, self).__init__(envelope)
+        self.envelope = envelope
