@@ -1,4 +1,3 @@
-
 import logging
 import abc
 
@@ -6,13 +5,15 @@ try:
     # noinspection PyUnresolvedReferences
     AbstractBaseClass = abc.ABC
 except AttributeError:  # pragma: no cover
-    AbstractBaseClass = abc.ABCMeta('ABC', (object,), {'__slots__': ()})
+    AbstractBaseClass = abc.ABCMeta("ABC", (object,), {"__slots__": ()})
 
 
 class SoapClient(AbstractBaseClass):
     # noinspection PyUnusedLocal
     def __init__(self, wsdl_url, key_data, cert_data, tbk_cert_data, password=None):
-        self.logger = logging.getLogger('tbk.soap.client.{}'.format(self.__class__.__name__))
+        self.logger = logging.getLogger(
+            "tbk.soap.client.{}".format(self.__class__.__name__)
+        )
         self.logger.info("Initializing soap client for wsdl: %s", wsdl_url)
 
     @abc.abstractmethod
@@ -24,5 +25,5 @@ class SoapClient(AbstractBaseClass):
         raise NotImplementedError
 
     @abc.abstractmethod
-    def request(self, method_name, *args, **kwargs):
+    def request(self, request, timeout=None):
         raise NotImplementedError
